import time
import random as r
import math

import graphics as g


def main():

    termSize = g.console.Size()
    screen = g.Canvas(border=False)

    # Clock Face
    circle = g.Sprite(
        g.shapes.Circle(0),
        color=g.colors.CYAN
    )
    textTime = g.Sprite(
        g.shapes.Text()
    )
    screen.sprites.append(circle)
    screen.sprites.append(textTime)

    # Hands
    second = g.Sprite(
        g.shapes.Vector(0, 0),
        color=g.colors.RED,
        char=chr(0x25CB)
    )
    minute = g.Sprite(
        g.shapes.Vector(0, 0),
        color=g.colors.YELLOW
    )
    hour = g.Sprite(
        g.shapes.Vector(0, 0),
        color=g.colors.YELLOW
    )
    screen.sprites.append(second)
    screen.sprites.append(minute)
    screen.sprites.append(hour)

    frames = 0
    start = time.time()
    try:
        while True:

            # Update sizes
            termS = termSize.getSize()
            size = int(min(termS[0] / 2,
                           termS[1]) - 1)
            center = size * .5

            screen.width = size
            screen.height = size
            circle.image.radius = center

            # Generate background
            background = [[' ' for x in range(size)]
                          for y in range(size)]

            hours = 12
            for n in range(1, hours + 1):
                angle = n * (2 * math.pi / hours)

                x = 0.8 * center * math.sin(angle)
                y = 0.8 * center * math.cos(angle)

                for offset, char in enumerate(list(str(n))):
                    bac = [slice(int(center - y)),
                           slice(int(center + x + offset))]
                    background[bac[0]][bac[1]] = g.colors.colorStr(char, n % 8)

            screen.background = background

            # Generate hands
            t = int(time.time())

            h = int((t / 3600) % 12)
            h = 12 if h == 0 else h
            m = int((t / 60) % 60)
            s = int((t / 1) % 60)
            textTime.image.text = '{:2}:{:02}:{:02}'.format(h, m, s)
            textTime.position = (center - (len(textTime.image.text) / 2),
                                 (3 / 4) * size)

            for hand, secPerRev, length in [(second, 60, 0.9),
                                            (minute, 3600, 0.75),
                                            (hour, 43200, 0.5)]:
                hand.image.length = center * length

                # +180 and -angle are to compensate for
                #   flipped upside-down angles.
                angle = (((t * (360 / secPerRev)) + 180) % 360)
                hand.image.angle = -angle

                width, height = hand.image.width, hand.image.height

                if angle > 0 and angle <= 90:
                    hand.position = (center - width, center)

                elif angle > 90 and angle <= 180:
                    hand.position = (center - width, center - height)

                elif angle > 180 and angle <= 270:
                    hand.position = (center, center - height)

                elif angle > 270 and angle <= 360:
                    hand.position = (center, center)

            print(screen, end='')
            time.sleep(0.1)
            frames += 1
    except KeyboardInterrupt:
        print('\nAvg FPS: ' + str(frames / (time.time() - start)))

if __name__ == '__main__':
    main()



import os
from .obstacles import *
from .config import *


def show_title_page():
    os.system('clear')
    print(Fore.RED+Style.BRIGHT+"\n"*5+" "*45+"SUPER MARIO"+" "*40)
    print(Fore.CYAN+"\n"*3+" "*30 + "Higher the level,\
          more the number of enemies\n")
    print(Fore.CYAN+" "*35 + " more gravity and faster movement\n\n")
    print(Fore.YELLOW+" "*43 + " Choose Wisely.\n")
    x = int(input(Fore.WHITE+" "*20+"Enter level (1/2/3) : "))
    return x


def generatescene(scene, level):
    # clouds
    x = 0
    for y in range(10, 500, 30):
        cloud = Cloud(3, 6)
        x = (x+2) % 7
        cloud.setPos(scene, x, y)
    # grass
    for y in range(55, 500, 45):
        grass = Grass(2, 3)
        x = groundx - grass.length
        grass.setPos(scene, x, y)
    # walls and pits
    Wall.draw_wall(scene, 6, 10, 30)
    Wall.draw_wall(scene, 15, 10, 40)

    wall = Wall(4, 35)
    wall.setPos(scene, groundx-9, 63)

    Pit.draw_pit(scene, 15, 78)

    Wall.draw_wall(scene, 6, 9, 108)
    Pit.draw_pit(scene, 8, 117)
    Wall.draw_wall(scene, 4, 17, 125)
    Pit.draw_pit(scene, 8, 142)

    wall = Wall(3, 10)
    wall.setPos(scene, groundx-8, 170)

    # place enemy on top
    wall = Wall(3, 15)
    wall.setPos(scene, groundx-10, 186)

    Pit.draw_pit(scene, 14, 188)

    wall = Wall(3, 10)
    wall.setPos(scene, groundx-8, 210)

    Pit.draw_pit(scene, 15, 230)

    wall = Wall(3, 5)
    wall.setPos(scene, groundx-7, 233)

    Wall.draw_wall(scene, 6, 10, 245)

    wall = Wall(3, 7)
    wall.setPos(scene, groundx-13, 258)

    Pit.draw_pit(scene, 15, 255)
    Wall.draw_wall(scene, 15, 10, 270)

    wall = Wall(4, 23)
    wall.setPos(scene, groundx-19, 285)
    wall = Wall(3, 22)
    wall.setPos(scene, groundx-27, 300)

    Pit.draw_pit(scene, 50, 280)

    Wall.draw_wall(scene, 15, 15, 330)
    Pit.draw_pit(scene, 10, 345)
    Wall.draw_wall(scene, 6, 10, 355)
    Pit.draw_pit(scene, 10, 365)

    Pit.draw_pit(scene, 100, 390)

    wall = Wall(3, 20)
    wall.setPos(scene, groundx-10, 390)

    wall = Wall(3, 20)
    wall.setPos(scene, groundx-18, 400)

    wall = Wall(3, 20)
    wall.setPos(scene, groundx-27, 410)

    wall = Wall(3, 20)
    wall.setPos(scene, groundx-10, 430)

    wall = Wall(3, 20)
    wall.setPos(scene, groundx-20, 440)

    wall = Wall(3, 13)
    wall.setPos(scene, groundx-25, 464)

    wall = Wall(3, 5)
    wall.setPos(scene, groundx-8, 480)



#This is the ultimate debugging tool when you know something weird is happening but you don't know where.
#This is kinda like hunter.py but it doesn't hav syntax errors and it can launch a debugger
def f():
    i=0
    for _ in range(100) :
        print('i=',i)
        i+=1
        i%=30
def set_pudb_trace_at_frame(frame,event,args):
    import pudb
    dbg = pudb._get_debugger()
    dbg.set_trace(frame)
    #dbg.break_here(frame)
    #dbg.stop_here(frame)
    dbg.trace_dispatch(frame, event, args)
def trap_namespace_tracer(**checks):
    #Really, we can put any kind of condition in here. This is just a demo that simply checks to see if there's an i=1 in the namespace.
    def tracer(frame,event,args):
        #TODO: Use 'event' to detect function calls to make new kinds of traps, such as when we're entering a function.
        #TODO: Take inspiration from hunter.py?
        flag=True
        print('TRACE')#For some reason this isn't printed after we exit the debugger. investigaet.\c
        for key,value in checks.items():
            namespace=frame.f_locals
            if key not in namespace or namespace[key]!=value:
                flag=False
        if flag:
            print('CAUGHT!!!')
            set_pudb_trace_at_frame(frame,event,args)
        return tracer#We must return the tracer otherwise python will lose track of it
    sys.settrace(tracer)
trap_namespace_tracer(i=19)
f()


rp.rp_ptpython
rp.prompt_toolkit
rp.rp_ptpdb
rp.libs.tetris
rp.libs.pyflann
rp.libs.tetris.graphics.graphics
rp.libs.pyflann.util
rp.libs.pyflann.io
rp.libs.pyflann.bindings
rp.prompt_toolkit.filters
rp.prompt_toolkit.layout
rp.prompt_toolkit.terminal
rp.prompt_toolkit.contrib
rp.prompt_toolkit.key_binding
rp.prompt_toolkit.styles
rp.prompt_toolkit.eventloop
rp.prompt_toolkit.clipboard
rp.prompt_toolkit.contrib.completers
rp.prompt_toolkit.contrib.regular_languages
rp.prompt_toolkit.contrib.validators
rp.prompt_toolkit.contrib.telnet
rp.prompt_toolkit.key_binding.bindings
rp